Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(7089)

Unified Diff: chrome/browser/ssl/security_state_tab_helper.h

Issue 2917873004: Implement 'Not secure' warning for non-secure pages in Incognito mode (Closed)
Patch Set: Ensure sensitive fields trigger warnings outside of Incognito Created 3 years, 6 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/ssl/security_state_tab_helper.h
diff --git a/chrome/browser/ssl/security_state_tab_helper.h b/chrome/browser/ssl/security_state_tab_helper.h
index f44e7f8a0eb8588cf05f15a54ba5d2db467bcc23..28c0cdb8862cbd42cfb75948933ad38942ad0914 100644
--- a/chrome/browser/ssl/security_state_tab_helper.h
+++ b/chrome/browser/ssl/security_state_tab_helper.h
@@ -50,9 +50,13 @@ class SecurityStateTabHelper
std::unique_ptr<security_state::VisibleSecurityState>
GetVisibleSecurityState() const;
- // True if a console message has been logged about an omnibox warning that
- // will be shown in future versions of Chrome for insecure HTTP pages. This
- // message should only be logged once per main-frame navigation.
+ // True if a console message has been logged about an omnibox warning shown
+ // when insecure HTTP pages are loaded in Incognito mode. This message should
+ // only be logged once per main-frame navigation.
+ bool logged_incognito_warning_on_current_navigation_;
+ // True if a console message has been logged about an omnibox warning shown
+ // when sensitive input fields are shown on insecure HTTP pages. This message
+ // should only be logged once per main-frame navigation.
bool logged_http_warning_on_current_navigation_;
// The time that a console or omnibox warning was shown for insecure

Powered by Google App Engine
This is Rietveld 408576698